@@ -1,6 +1,6 @@
 package Class::Load;
 {
-  $Class::Load::VERSION = '0.09';
+  $Class::Load::VERSION = '0.10';
 }
 use strict;
 use warnings;
@@ -79,6 +79,9 @@ sub load_first_existing_class {
     for my $class (@{$classes}) {
         my ($name, $options) = @{$class};
 
+        _croak("$name is not a module name")
+            unless _is_module_name($name);
+
         # We need to be careful not to pass an undef $options to this sub,
         # since the XS version will blow up if that happens.
         return $name if is_class_loaded($name, ($options ? $options : ()));
@@ -136,6 +139,9 @@ sub load_optional_class {
     my $class   = shift;
     my $options = shift;
 
+    _croak("$class is not a module name")
+        unless _is_module_name($class);
+
     my ($res, $e) = try_load_class($class, $options);
     return 1 if $res;
 
@@ -165,8 +171,6 @@ sub _is_module_name {
 sub _mod2pm {
     my $class = shift;
 
-    _croak("$class is not a module name")
-        unless _is_module_name($class);
     $class =~ s+::+/+g;
     return "$class.pm";
 }
@@ -175,6 +179,9 @@ sub try_load_class {
     my $class   = shift;
     my $options = shift;
 
+    _croak("$class is not a module name")
+        unless _is_module_name($class);
+
     local $@;
     undef $ERROR;
 
@@ -243,7 +250,7 @@ Class::Load - a working (require "Class::Name") and more
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
